# use fakeroot -ba sudo.spec to build!

Name:           sudo
Version:        1.8.6p7
Release:        %mkrel 1
Epoch:          1
Summary:        Allows command execution as root for specified users
License:        GPLv2+
Group:          System/Base
URL:            http://www.sudo.ws/sudo
Source0:        http://www.sudo.ws/sudo/dist/%{name}-%{version}%{?pre}.tar.gz
Source1:        http://www.sudo.ws/sudo/dist/%{name}-%{version}%{?pre}.tar.gz.sig
Source2:        sudo.pamd
Source3:        sudo-1.7.2p2-sudoers
Patch1:         sudo-1.6.7p5-strip.patch
Patch2:         sudo-1.7.2p1-envdebug.patch
Patch3:         sudo-1.8.6p1-m4path.patch
Patch4:		sudo-1.8.5-pipelist.patch
BuildRequires:  audit-devel
BuildRequires:  bison
BuildRequires:  groff-for-man
BuildRequires:  libcap-devel
BuildRequires:  openldap-devel
BuildRequires:  pam-devel
Requires(pre):  openldap

%description
Sudo (superuser do) allows a system administrator to give certain users (or
groups of users) the ability to run some (or all) commands as root while
logging all commands and arguments. Sudo operates on a per-command basis.
It is not a replacement for the shell. Features include: the ability to
restrict what commands a user may run on a per-host basis, copious logging
of each command (providing a clear audit trail of who did what), a
configurable timeout of the sudo command, and the ability to use the same
configuration file (sudoers) on many different machines.

%package devel
Summary:        Development files for sudo plugins
Group:          Development/C
Requires:       %{name} = %{epoch}:%{version}-%{release}

%description    devel
Development files for compiling sudo plugins.

%prep
%setup -q -n %{name}-%{version}%{?pre}
%patch1 -p1 -b .strip
%patch2 -p1 -b .envdebug
%patch3 -p1 -b .m4path
%patch4 -p1 -b .pipelist

# fix attribs
find -name "Makefile.*" | xargs perl -pi -e "s|-m 0444|-m 0644|g"


%build
# handle newer autoconf
rm -f acsite.m4
mv aclocal.m4 acinclude.m4
autoreconf -fv --install

%serverbuild
export CFLAGS="%{optflags} -D_GNU_SOURCE"

%configure2_5x \
        --without-rpath \
        --with-logging=both \
        --with-logfac=authpriv \
        --with-logpath=%{_logdir}/sudo.log \
        --with-editor=/bin/vi \
        --enable-log-host \
        --with-pam \
        --with-pam-login \
        --with-env-editor \
        --with-noexec=no \
        --with-linux-audit \
        --with-ignore-dot \
        --with-tty-tickets \
        --with-ldap \
        --with-ldap-conf-file=%{_sysconfdir}/ldap.conf \
        --with-secure-path="/sbin:%{_sbindir}:/bin:%{_bindir}:/usr/local/bin:/usr/local/sbin" \
        --with-passprompt="[sudo] password for %p: " \
        --with-plugindir=%{_libdir}/sudo

%make

%install
rm -rf %{buildroot}

install -d %{buildroot}/usr
install -d %{buildroot}%{_sysconfdir}/logrotate.d
install -d %{buildroot}%{_sysconfdir}/sudoers.d
install -d %{buildroot}%{_sysconfdir}/pam.d
install -d %{buildroot}%{_var}/db/sudo
install -d %{buildroot}%{_logdir}/sudo
install -d %{buildroot}%{_logdir}/sudo-io

%makeinstall_std install_uid=$UID install_gid=$(id -g) sudoers=uid=$UID sudoers_gid=$(id -g)

install -m0644 %{SOURCE2} %{buildroot}%{_sysconfdir}/pam.d/sudo
install -m0644 %{SOURCE3} %{buildroot}%{_sysconfdir}/sudoers
install -m0755 plugins/sudoers/sudoers2ldif %{buildroot}%{_bindir}

# Installing logrotated file
cat <<END >%{buildroot}%{_sysconfdir}/logrotate.d/sudo
%{_logdir}/sudo.log {
    missingok
    monthly
    compress
}
END

cat > %{buildroot}%{_sysconfdir}/pam.d/sudo << EOF
#%PAM-1.0
auth            include         system-auth
account         include         system-auth
password        include         system-auth
session         optional        pam_keyinit.so revoke
session         required        pam_limits.so
EOF

cat > %{buildroot}%{_sysconfdir}/pam.d/sudo-i << EOF
#%PAM-1.0
auth            include         sudo
account         include         sudo
password        include         sudo
session         optional        pam_keyinit.so force revoke
session         required        pam_limits.so
EOF

# so that strip can touch it...
chmod 755 %{buildroot}%{_bindir}/*
chmod 755 %{buildroot}%{_sbindir}/*

# (tpg) create the missing log file
touch %{buildroot}%{_logdir}/sudo.log

%find_lang sudo
%find_lang sudoers

cat sudo.lang sudoers.lang > sudo_all.lang
rm sudo.lang sudoers.lang

%check
make check

%post
/bin/chmod 0440 %{_sysconfdir}/sudoers || :
%create_ghostfile %{_logdir}/sudo.log root root 600

%files -f sudo_all.lang
%doc doc/HISTORY README README.LDAP
%doc doc/TROUBLESHOOTING doc/UPGRADE doc/sample.* doc/schema.*
%attr(0440,root,root) %config(noreplace) %{_sysconfdir}/sudoers
%attr(0750,root,root) %dir %{_sysconfdir}/sudoers.d/
%config(noreplace) %{_sysconfdir}/logrotate.d/sudo
%config(noreplace) %{_sysconfdir}/pam.d/sudo
%config(noreplace) %{_sysconfdir}/pam.d/sudo-i
%attr(0755,root,root) %{_bindir}/sudoers2ldif
%attr(4111,root,root) %{_bindir}/sudo
%attr(4111,root,root) %{_bindir}/sudoedit
%attr(0111,root,root) %{_bindir}/sudoreplay
%attr(0755,root,root) %{_sbindir}/visudo
%ghost %{_logdir}/sudo.log
%{_mandir}/*/*
%attr(0700,root,root) %dir %{_var}/db/sudo
%attr(0750,root,root) %dir %{_logdir}/sudo-io
%{_libdir}/sudo/sudoers.so

%files devel
%doc plugins/{sample,sample_group}
%{_includedir}/sudo_plugin.h
%{_mandir}/man8/sudo_plugin.8*


%changelog

* Thu Feb 28 2013 luigiwalser <luigiwalser> 1:1.8.6p7-1.mga3
+ Revision: 400679
- 1.8.6p7

* Tue Feb 12 2013 luigiwalser <luigiwalser> 1:1.8.6p6-1.mga3
+ Revision: 397943
- 1.8.6p6

* Thu Jan 31 2013 luigiwalser <luigiwalser> 1:1.8.6p5-1.mga3
+ Revision: 393626
- 1.8.6p5

* Mon Jan 14 2013 umeabot <umeabot> 1:1.8.6p3-3.mga3
+ Revision: 383578
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sun Jan 06 2013 pterjan <pterjan> 1:1.8.6p3-2.mga3
+ Revision: 340151
- Place plugins in /usr/lib/sudo/ instead of libexecdir, they are .so to dlopen

* Sun Sep 23 2012 luigiwalser <luigiwalser> 1:1.8.6p3-1.mga3
+ Revision: 296897
- 1.8.6p3

* Sat Sep 15 2012 luigiwalser <luigiwalser> 1:1.8.6p1-1.mga3
+ Revision: 294256
- 1.8.6p1
- rediff patch 3
- remove upstreamed patch 5

* Sun Jul 29 2012 luigiwalser <luigiwalser> 1:1.8.5p1-1.mga3
+ Revision: 275808
- 1.8.5p1
- add pipelist and sssd-support patches from mdv
- other minor syncing with mdv package

* Thu May 17 2012 luigiwalser <luigiwalser> 1:1.8.3p2-2.mga3
+ Revision: 235868
- add patch for CVE-2012-2337 (improper netmask matching)

* Mon Jan 30 2012 boklm <boklm> 1:1.8.3p2-1.mga2
+ Revision: 203379
- Version 1.8.3.p2 (fixing format string vulnerability)

* Mon Oct 31 2011 fwang <fwang> 1:1.8.3p1-1.mga2
+ Revision: 160282
- new version 1.8.3p1

* Fri Oct 07 2011 shlomif <shlomif> 1:1.8.2-1.mga2
+ Revision: 152774
- New version of sudo - 1.8.2. Patch to SPEC contributed by barjac.

  + rtp <rtp>
    - fix build with noexec disabled
    - fix file list

  + tv <tv>
    - drop patch 5 (merged upstream)
    - new release

* Thu Mar 24 2011 pterjan <pterjan> 1:1.8.0-4.mga1
+ Revision: 76858
- Fix missing epoch in -devel dependency

* Wed Mar 23 2011 blino <blino> 1:1.8.0-3.mga1
+ Revision: 75835
- fix exit value of sudo -l command in sudoers module (from upstream)

* Mon Mar 21 2011 dmorgan <dmorgan> 1:1.8.0-2.mga1
+ Revision: 75107
- Add upstream patch for fix the use of the -n option ( Bug #475)

* Sat Mar 19 2011 boklm <boklm> 1:1.8.0-1.mga1
+ Revision: 74482
- update to version 1.8.0
- removed patches :
 * sudo-1.7.4p4-auditconn.patch: removed from fedora package
 * sudo-1.7.4p3-sudolist.patch: removed from fedora package
 * sudo-1.7.4p4-sudoi.patch: applied upstream
 * sudo-1.7.4p4-getgrouplist.patch: does not apply to new version, and
   needs small modifications. Fixing Red Hat bug #235915, but not applied
   upstream since 2007.

  + blino <blino>
    - imported package sudo

